% Build sampling matrix for the optimization problem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DataFlag(i,j):    wafer data flag
%                   1 if (i,j) is a chip
%                   0 otherwise
% SampleX(i,1):     coordinates of measurements (X-axis)
% SampleY(i,1):     coordinates of measurements (Y-axis)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% EqnA(i,j):        sampling matrix A for VP problem:
%                   min ||x||_1 s.t. Ax=b
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function EqnA = buildEqnA(DataFlag,SampleX,SampleY)

% problem dimensions
NumExp = length(SampleX);
XMax = size(DataFlag,1);
YMax = size(DataFlag,2);
NumF = XMax*YMax;

% build linear equation
IndexP = repmat(1:XMax,[1 YMax]);
IndexQ = zeros(1,NumF);
for j = 1:YMax
    IndexQ((j-1)*XMax+1:j*XMax) = j*ones(1,XMax);
end

AlphaP = zeros(size(IndexP));
AlphaP(IndexP==1) = sqrt(1/XMax);
AlphaP(IndexP>=2) = sqrt(2/XMax);

AlphaQ = zeros(size(IndexQ));
AlphaQ(IndexQ==1) = sqrt(1/YMax);
AlphaQ(IndexQ>=2) = sqrt(2/YMax);

EqnA = zeros(NumExp,NumF); 
for i = 1:NumExp
    cur_x = SampleX(i);
    cur_y = SampleY(i);
    cur_a = AlphaP .* AlphaQ .* cos(pi*(2*cur_x-1)*(IndexP-1)/2/XMax) .* cos(pi*(2*cur_y-1)*(IndexQ-1)/2/YMax);
    EqnA(i,:) = cur_a;
end