% generate random samples using Latin Hypercube Sampling
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DataFlag(i,j):    input data flag
%                   1 if (i,j) is measured
%                   0 otherwise
% NumExp:           # of samples
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SampleX(i,1):     coordinates of samples (X-axis)
% SampleY(i,1):     coordinates of samples (Y-axis)
% index:            label of samples
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [SampleX,SampleY,index] = gen_lhs_sample(DataFlag,NumExp)

% initialization
XMax = size(DataFlag,1);
YMax = size(DataFlag,2);
NumF = XMax*YMax;
index = zeros(NumExp,1);

[IndexX,IndexY] = find(DataFlag == 1);
NumExpTotal = length(IndexX);

% divide bins
base_size = floor(NumExpTotal/NumExp);
bin_size = ones(NumExp,1)*base_size;

% randomly distribute the remaining slots
remain_size = mod(NumExpTotal,NumExp);
inc_bins = 1:NumExp;
% randomly pick remain_size bins 
[ans,myorder]=sort(rand(1,NumExp));
inc_bins = inc_bins(myorder(1:remain_size));
bin_size(inc_bins) = bin_size(inc_bins) + 1;

% generate random samples
SampleX = zeros(NumExp,1);
SampleY = zeros(NumExp,1);
cur_start = 1;
for j = 1:NumExp
    cur_binsize = bin_size(j);
    % generate a random number from 0 to binsize-1
    cur_rand = floor(rand*cur_binsize);
    SampleX(j) = IndexX(cur_start + cur_rand);
    SampleY(j) = IndexY(cur_start + cur_rand);
    index(j) = cur_start + cur_rand;
    cur_start = cur_start + cur_binsize;
end
