% Generate optimal samples, minimizing coherence statistic
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DataFlag(i,j):    input data flag
%                   1 if (i,j) is measured
%                   0 otherwise
% NumExp:           # of samples
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SampleX(i,1):     coordinates of samples (X-axis)
% SampleY(i,1):     coordinates of samples (Y-axis)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [SampleX,SampleY] = gen_opt_sample(DataFlag,NumExp)

min_mu = Inf;
[IndexX,IndexY] = find(DataFlag == 1);
XMax = size(DataFlag,1);
YMax = size(DataFlag,2);
% build EqnA for all samples
EqnA_full = buildEqnA(DataFlag,IndexX,IndexY);

for iter = 1:100
    [SampleX_i,SampleY_i,index] = gen_lhs_sample(DataFlag,NumExp);
    EqnA = EqnA_full(index,:);
    % normalize linear equation
    MeanA = mean(EqnA,1);
    DCIndex = 1; MeanA(DCIndex) = 0;
    EqnA = EqnA - repmat(MeanA,NumExp,1);
    ScaleA = sqrt(sum(EqnA.^2,1));
    EqnA = EqnA ./ repmat(ScaleA,NumExp,1);
    % test the coherence statistic for current sampling points
    cur_max_mu = test_coherence(EqnA,min_mu);
    if cur_max_mu < min_mu
        min_mu = cur_max_mu;
        SampleX = SampleX_i;
        SampleY = SampleY_i;
    end
end