% Solve L1-regularization problem with inequality constraint
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% EqnA(i,j):        sampling matrix A for VP problem:
%                   min ||x||_1+ lambda * ||Ax=b||^2_2
% EqnB(i,1):        data vector b for the above problem
%                   EqnB is assumed to be normalized
% lambda:           the lambda factor in VP problem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DataF(i,j):       solution of the above problem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function DataF = solve_l1_ineq(EqnA,EqnB,lambda)

NumExp = size(EqnA,1);
NumF = size(EqnA,2);
% normalize columns of EqnA
% EqnB is assumed to be already normalized 
MeanA = mean(EqnA,1);
DCIndex = 1; MeanA(DCIndex) = 0;
EqnA = EqnA - repmat(MeanA,NumExp,1);
ScaleA = sqrt(sum(EqnA.^2,1))/sqrt(NumExp);

% eliminate numerical issues in scaling
MeanScale = mean(ScaleA);
for i = 1:NumF
    if ScaleA(i) < 1e-2 * MeanScale
        ScaleA(i) = MeanScale;
    end
end

EqnA = EqnA ./ repmat(ScaleA,NumExp,1);

% solve the problem after normalization
DataF = l1_ls(EqnA,EqnB,lambda,1e-3,true);

% de-normalize linear equation
DataF = DataF ./ ScaleA';
DataF(DCIndex) = DataF(DCIndex) - MeanA*DataF/ScaleA(DCIndex);

