% Test the coherence statistic of sampling matrix EqnA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% EqnA(i,j):        sampling matrix A for VP problem:
%                   min ||x||_1 s.t. Ax=b
%                   0 otherwise
% min_mu:           threshold for coherence to reduce complexity
%                   (optional)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mu:               coherence of EqnA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function mu = test_coherence(EqnA,min_mu)
if nargin < 2
    min_mu = Inf;
end
% initialization
NumF = size(EqnA,2);
NumExp = size(EqnA,1);

% test coherence
mu = 0;
for i = 1:NumF
    phi_i = EqnA(:,i);
    for j = i+1:NumF
        phi_j = EqnA(:,j);
        cur_mu = abs(phi_i'*phi_j);    
        if cur_mu > mu
            mu = cur_mu;
            % if mu already too large, return
            if mu > min_mu
                return;
            end
        end
    end
end

