% Test the performance of VP on known wafer
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PerfData(i,j):    chip performances on a wafer, locations without no chip
%                   filled with NaN
% NumExp:           # of actual measurements
% noise(boolean):   whether measurements contain significant noise
%                   (optional, default = false)           
% SampleX(i,1):     coordinates of measurements (X-axis)
%                   (optional)
% SampleY(i,1):     coordinates of measurements (Y-axis)
%                   (optional)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% error:            relative error for VP
% PerfEst(i,j):     recovered wafer map by VP
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [error,PerfEst] = test_vp(PerfData,NumExp,noise,SampleX,SampleY)

% determine chip locations
DataFlag = (PerfData>=0|PerfData<0);

% set default parameter
if nargin < 3
    noise = false;
end
% generate measurement locations, if needed
if nargin < 4
    [SampleX,SampleY] = gen_lhs_sample(DataFlag,NumExp);
end

SampleData = zeros(NumExp,1);
for i = 1:NumExp
    SampleData(i) = PerfData(SampleX(i),SampleY(i));
end

PerfEst = solve_vp(SampleData,SampleX,SampleY,DataFlag,noise);

% calculate error
index = find(DataFlag==1);
error = norm(PerfEst(index)-PerfData(index),'fro')/norm(PerfData(index),'fro');
fprintf('#Samples = %g, Error = %g\n',NumExp,error);